==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/test/t_Library_cpp.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_Library_cpp.cxx
 *  @brief The test file of class Library with C++ symbols
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-09-28 12:38:16 +0200 (ven 28 sep 2007) $
 *  Id:      $Id: t_Library_cpp.cxx 551 2007-09-28 10:38:16Z dutka $
 */
#include <iostream>
#include <sstream>
#include <exception>
#include <cstdlib>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "LibraryLoader.hxx"
#include "Library.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Func;


int main(int argc, char *argv[])
{
  TESTPREAMBLE;

  try {
    const String path(std::getenv("OPENTURNS_WRAPPER_PATH"));

    /** Instance creation */
    LibraryLoader & loader = LibraryLoader::GetInstance();

    try {
      String libraryPath1 = path + "/testwrapper_2.so";
      Library library = loader.load( libraryPath1.c_str() );
      std::cout << loader  << std::endl;
      std::cout << library << std::endl;

      OT::LibrarySymbol symbol = library.getSymbol("fonction2");
      std::cout << "Symbol found at address " << symbol << std::endl;


    }
    catch (DynamicLibraryException & ex) {
      throw TestFailed(ex.str());
    }


  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }

  return OT::Test::ExitCode::Success;
}

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/test/t_Library_cpp.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_Library_cpp.cxx
 *  @brief The test file of class Library with C++ symbols
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: t_Library_cpp.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include <iostream>
#include <sstream>
#include <exception>
#include <cstdlib>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "LibraryLoader.hxx"
#include "Library.hxx"

using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Common;
using namespace OT::Base::Func;


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try {
    const String path(std::getenv("OPENTURNS_WRAPPER_PATH"));

    /** Instance creation */
    LibraryLoader & loader = LibraryLoader::GetInstance();

    try {
#ifndef WIN32
      String libraryPath1 = path + "/testwrapper_2.so";
#else
      String libraryPath1 = path + "/testwrapper_2-0.dll";
#endif
      Library library = loader.load( libraryPath1.c_str() );
      fullprint << loader  << std::endl;
      fullprint << library << std::endl;

      OT::LibrarySymbol symbol = library.getSymbol("fonction2");
      fullprint << "Symbol found at address " << symbol << std::endl;


    }
    catch (DynamicLibraryException & ex) {
      throw TestFailed(ex.__repr__());
    }


  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }

  return OT::Test::ExitCode::Success;
}
